@@ -34,6 +34,8 @@ INFIX_OP_TO_FUNC = {
     "<=": operator.OP_LE,
 }
 
+MAX_EMPTY = 1000
+
 
 class EvalContext:
 
@@ -42,15 +44,24 @@ class EvalContext:
     namespace = None
     seen = None
     ref = None
+    refsheet = None
+    sheet = None
 
     def __init__(self, namespace=None, ref=None, seen=None):
         self.seen = seen if seen is not None else []
         self.namespace = namespace if namespace is not None else xl.FUNCTIONS
         self.ref = ref
+        self.sheet = self.refsheet = ref.split("!")[0]
 
     def eval_cell(self, addr):
         raise NotImplementedError()
 
+    def set_sheet(self, sheet=None):
+        if sheet is None:
+            self.sheet = self.refsheet
+        else:
+            self.sheet = sheet
+
 
 class ASTNode(object):
     """A generic node in the AST"""
@@ -127,28 +138,43 @@ class RangeNode(OperandNode):
     def address(self):
         return self.tvalue
 
-    def full_address(self, ref):
+    def full_address(self, context):
         addr = self.address
         if '!' not in addr:
-            sheet, _, _ = utils.resolve_address(ref)
-            addr = f'{sheet}!{addr}'
+            addr = f'{context.sheet}!{addr}'
         return addr
 
     def eval(self, context):
-        addr = self.full_address(context.ref)
+        addr = self.full_address(context)
 
         if addr in context.ranges:
-            range_cells = [
-                [
-                    context.eval_cell(addr)
-                    for addr in range_row
-                ]
-                for range_row in context.ranges[addr].cells
-            ]
+            empty_row = 0
+            empty_col = 0
+            range_cells = []
+            for range_row in context.ranges[addr].cells:
+                row_cells = []
+                for col_addr in range_row:
+                    cell = context.eval_cell(col_addr)
+                    if cell.value == '' or cell.value is None:
+                        empty_col += 1
+                        if empty_col > MAX_EMPTY:
+                            break
+                    else:
+                        empty_col = 0
+                    row_cells.append(cell)
+                if not row_cells:
+                    empty_row += 1
+                    if empty_row > MAX_EMPTY:
+                        break
+                else:
+                    empty_row = 0
+                range_cells.append(row_cells)
             context.ranges[addr].value = data = func_xltypes.Array(range_cells)
             return data
 
-        return context.eval_cell(addr)
+        value = context.eval_cell(addr)
+        context.set_sheet()
+        return value
 
 
 class OperatorNode(ASTNode):
