@@ -28,7 +28,7 @@ class EvaluatorContext(ast_nodes.EvalContext):
                 f'Cycle detected for {addr}:\n- ' + '\n- '.join(self.seen))
         self.seen.append(addr)
 
-        return self.evaluator.evaluate(addr, self)
+        return self.evaluator.evaluate(addr, None)
 
 
 class Evaluator:
